﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Xunit;
using Domain;
using System.Data.Entity;

namespace DomainTests
{
	public class DomainContextSpec
	{
		public DomainContextSpec()
		{
			Database.SetInitializer<DomainContext>(new DropCreateDatabaseAlways<DomainContext>());
		}

		[Fact]
		public void WhenCreatingProduct_ThenCanSaveIt()
		{
			var product = new Product { Title = "WoVS" };
			using (IDomainContext context = new DomainContext())
			{
				context.Save(product);
				context.SaveChanges();
			}

			using (IDomainContext context = new DomainContext())
			{
				var saved = context.Products.FirstOrDefault(x => x.Id == product.Id);

				Assert.NotNull(saved);
				Assert.Equal(product.Title, saved.Title);
			}
		}

		[Fact]
		public void WhenDeletingProduct_ThenCanNotReadIt()
		{
			var product = new Product { Title = "WoVS" };
			using (IDomainContext context = new DomainContext())
			{
				context.Save(product);
				context.SaveChanges();
			}

			using (IDomainContext context = new DomainContext())
			{
				context.Delete<Product>(product.Id);
				context.SaveChanges();
			}

			using (IDomainContext context = new DomainContext())
			{
				var saved = context.Products.FirstOrDefault(x => x.Id == product.Id);

				Assert.Null(saved);
			}
		}
	}
}
