﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Xunit;
using Moq;
using Domain;

namespace DomainTests
{
	// Shows how we're unit testing some piece of business logic 
	// without a real database and using the IDomainContext as 
	// the entry point for mocks.
	public class StoreSpec
	{
		[Fact]
		public void WhenProductToPurchaseDoesNotExist_ThenThrowsNewArgumentException()
		{
			var products = new[] 
			{ 
				new Product { Id = 1 },
			};

			var context = Mock.Of<IDomainContext>(x => x.Products == products.AsQueryable());
			var store = new Store(context);

			Assert.Throws<ArgumentException>(() => store.Purchase(2, 1));
		}

		[Fact]
		public void WhenProductToPurchaseExists_ThenIncrementsSalesAndSavesChanges()
		{
			var products = new[] 
			{ 
				new Product { Id = 1, Sales = 25 },
			};

			var context = Mock.Of<IDomainContext>(x => x.Products == products.AsQueryable());
			var store = new Store(context);

			store.Purchase(1, 5);

			Assert.Equal(26, products[0].Sales);
			Mock.Get(context)
				.Verify(x => x.SaveChanges());
		}
	}
}
